Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Default = New()
)
Functions ¶
Types ¶
type EnvironmentSettings ¶
type EnvironmentSettings struct {
// Paths to external commands
Path
KubeConfig *rest.Config
KubeConfigPath string
// MaxHistory is the max tests history maintained.
MaxHistory int
// Debug indicates whether Frisbee is running in Debug mode.
Debug bool
// Debug indicates whether Frisbee CLI will provide hints for commands.
Hints bool
// OutputType indicate the format out message in the output.
OutputType string
// GoTemplate (if selected by OutputType type)
GoTemplate string
// contains filtered or unexported fields
}
EnvironmentSettings describes all the environment settings.
func New ¶
func New() *EnvironmentSettings
func (*EnvironmentSettings) AddFlags ¶
func (env *EnvironmentSettings) AddFlags(cmd *cobra.Command)
AddFlags binds flags to the given flagset.
func (*EnvironmentSettings) GetFrisbeeClient ¶
func (env *EnvironmentSettings) GetFrisbeeClient() *frisbeeclient.APIClient
GetFrisbeeClient returns api client
func (*EnvironmentSettings) Hint ¶
func (env *EnvironmentSettings) Hint(msg string, sub ...string)
func (*EnvironmentSettings) LookupBinaries ¶
func (env *EnvironmentSettings) LookupBinaries()
Click to show internal directories.
Click to hide internal directories.